@@ -1,8 +1,8 @@
-from .util import file_vector_field, vector_norm_scalar_field, \
-    setup_scalar_parameter, setup_vector_parameter, \
-    box_atlas, setup_m0
-from .mesh import mesh_script
-from .energy import energy_script
-from .system import system_script
-from .evolver import evolver_script
 from .driver import driver_script
+from .energy import energy_script
+from .evolver import evolver_script
+from .mesh import mesh_script
+from .system import system_script
+from .util import (box_atlas, file_vector_field, setup_m0,
+                   setup_scalar_parameter, setup_vector_parameter,
+                   vector_norm_scalar_field)
