@@ -1,9 +1,10 @@
-import sys
 import numbers
-import oommfc as oc
 import warnings
+
 import discretisedfield as df
 
+import oommfc as oc
+
 
 def energy_script(system):
     mif = ''
@@ -66,21 +67,21 @@ def zeeman_script(term, system):
                 FutureWarning)
         if isinstance(term.H, (df.Field, dict)):
             if term.wave == 'sin' or term.func == 'sin':
-                mif += 'proc TimeFunction { total_time } {\n'
+                mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
                 mif += f'  set tt [expr {{ $total_time - {term.t0} }}]\n'
-                mif += f'  set wt [expr {{ $w*$tt }}]\n'
+                mif += '  set wt [expr { $w*$tt }]\n'
                 mif += '  set f [expr {sin($wt)}]\n'
                 mif += '  set df [expr {$w*cos($wt)}]\n'
-                mif += f'  set ft [expr {{ $f }}]\n'
-                mif += f'  set dft [expr {{ $df }}]\n'
+                mif += '  set ft [expr { $f }]\n'
+                mif += '  set dft [expr { $df }]\n'
                 mif += ('  return [list $ft 0 0 0 $ft 0 0 0 $ft '
                         '$dft 0 0 0 $dft 0 0 0 $dft ] \n')
                 mif += '}\n\n'
 
             elif term.wave == 'sinc' or term.func == 'sinc':
-                mif += 'proc TimeFunction { total_time } {\n'
+                mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
                 mif += f'  set tt [expr {{ $total_time - {term.t0} }}]\n'
@@ -92,26 +93,26 @@ def zeeman_script(term, system):
                 mif += ('  if {$wt != 0} { set df '
                         '[expr {($wt*$w*$coswt - $w*$sinwt)/($wt*$wt)}] }\n')
                 mif += '  if {$wt == 0} { set df [expr {0}] }\n'
-                mif += f'  set ft [expr {{ $f }}]\n'
-                mif += f'  set dft [expr {{ $df }}]\n'
+                mif += '  set ft [expr { $f }]\n'
+                mif += '  set dft [expr { $df }]\n'
                 mif += ('  return [list $ft 0 0 0 $ft 0 0 0 $ft '
                         '$dft 0 0 0 $dft 0 0 0 $dft ] \n')
                 mif += '}\n\n'
 
             mif += '# TransformZeeman\n'
             mif += f'Specify Oxs_TransformZeeman:{term.name} {{\n'
-            mif += f'  type general\n'
-            mif += f'  script_args total_time\n'
-            mif += f'  script TimeFunction\n'
+            mif += '  type general\n'
+            mif += '  script_args total_time\n'
+            mif += f'  script TimeFunction:{term.name}\n'
             mif += f'  field {Hname}\n'
             mif += '}\n\n'
         else:
             if term.wave == 'sin' or term.func == 'sin':
-                mif += 'proc TimeFunction { total_time } {\n'
+                mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
                 mif += f'  set tt [expr {{ $total_time - {term.t0} }}]\n'
-                mif += f'  set wt [expr {{ $w*$tt }}]\n'
+                mif += '  set wt [expr { $w*$tt }]\n'
                 mif += '  set f [expr {sin($wt)}]\n'
                 mif += '  set df [expr {$w*cos($wt)}]\n'
                 mif += f'  set Hx [expr {{ {term.H[0]}*$f }}]\n'
@@ -123,7 +124,7 @@ def zeeman_script(term, system):
                 mif += '  return [list $Hx $Hy $Hz $dHx $dHy $dHz ] \n'
                 mif += '}\n\n'
             elif term.wave == 'sinc' or term.func == 'sinc':
-                mif += 'proc TimeFunction { total_time } {\n'
+                mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
                 mif += '  set PI [expr {4*atan(1.)}]\n'
                 mif += f'  set w [expr {{ {term.f}*2*$PI }}]\n'
                 mif += f'  set tt [expr {{ $total_time - {term.t0} }}]\n'
@@ -146,12 +147,12 @@ def zeeman_script(term, system):
 
             mif += '# ScriptUZeeman\n'
             mif += f'Specify Oxs_ScriptUZeeman:{term.name} {{\n'
-            mif += f'  script_args total_time\n'
-            mif += f'  script TimeFunction\n'
+            mif += '  script_args total_time\n'
+            mif += f'  script TimeFunction:{term.name}\n'
             mif += '}\n\n'
     elif hasattr(term, 'tlist'):
         if isinstance(term.H, (df.Field, dict)):
-            mif += 'proc TimeFunction { total_time } {\n'
+            mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
             mif += f'  set tstep {term.dt}\n'
             mif += '  set index [expr round($total_time/$tstep)]\n'
             tstr = ' '.join(map(str, term.tlist))
@@ -180,11 +181,11 @@ def zeeman_script(term, system):
             else:
                 mif += '  type diagonal\n'
             mif += '  script_args total_time\n'
-            mif += '  script TimeFunction\n'
+            mif += f'  script TimeFunction:{term.name}\n'
             mif += f'  field {Hname}\n'
             mif += '}\n\n'
         else:
-            mif += 'proc TimeFunction { total_time } {\n'
+            mif += f'proc TimeFunction:{term.name} {{ total_time }} {{\n'
             mif += f'  set tstep {term.dt}\n'
             mif += '  set index [expr round($total_time/$tstep)]\n'
             mif += f'  set H_t_fac {{ {" ".join(map(str, term.tlist))} }}\n'
@@ -202,8 +203,8 @@ def zeeman_script(term, system):
 
             mif += '# ScriptUZeeman\n'
             mif += f'Specify Oxs_ScriptUZeeman:{term.name} {{\n'
-            mif += f'  script_args total_time\n'
-            mif += f'  script TimeFunction\n'
+            mif += '  script_args total_time\n'
+            mif += f'  script TimeFunction:{term.name}\n'
             mif += '}\n\n'
     elif isinstance(term.tcl_strings, dict):
         mif += term.tcl_strings['script']
@@ -415,7 +416,7 @@ def rkky_script(term, system):
     mif += f'    region {first_name}\n'
     mif += '    scalarfield :rkkyfield\n'
     mif += f'    scalarvalue {first.pmax[df.util.axesdict[direction]]}\n'
-    mif += f'    scalarside -\n'
+    mif += '    scalarside -\n'
     mif += '  }\n'
 
     mif += '  surface2 {\n'
@@ -423,7 +424,7 @@ def rkky_script(term, system):
     mif += f'    region {second_name}\n'
     mif += '    scalarfield :rkkyfield\n'
     mif += f'    scalarvalue {second.pmin[df.util.axesdict[direction]]}\n'
-    mif += f'    scalarside +\n'
+    mif += '    scalarside +\n'
     mif += '  }\n'
 
     mif += '}\n\n'
